==> _private_chat-0.0.5.tar.gz: lib/widgets/widget_time_picker.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:_private_core/_private_core.dart';

class WidgetTimePicker extends StatefulWidget {
  final Function(DateTime) onTimeChange;
  final DateTime? initialSelectedDate;
  const WidgetTimePicker(
      {Key? key, required this.onTimeChange, this.initialSelectedDate})
      : super(key: key);

  @override
  _WidgetTimePickerState createState() => _WidgetTimePickerState();
}

class _WidgetTimePickerState extends State<WidgetTimePicker> {
  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.center,
      children: [
        Container(
          width: Get.width,
          height: 46,
          decoration: BoxDecoration(
              color: appColors.appBGColor,
              borderRadius: BorderRadius.circular(8)),
        ),
        Text(
          ':',
          style: robotoBold.copyWith(
              color: appColors.text, fontWeight: FontWeight.w500, fontSize: 20),
        ),
        // TimePickerSpinner(
        //   is24HourMode: true,
        //   time: widget.initialSelectedDate,
        //   normalTextStyle:  robotoBold.copyWith(
        //       color: AppColors.text.withOpacity(.65),
        //       fontWeight: FontWeight.w500,
        //       fontSize: 16.5),
        //   highlightedTextStyle:  robotoBold.copyWith(
        //       color: AppColors.text,
        //       fontWeight: FontWeight.w500,
        //       fontSize: 20),
        //   spacing: 16,
        //   itemHeight: 55,
        //   itemWidth: 55,
        //   isForce2Digits: true,
        //   alignment: Alignment.center,
        //   onTimeChange: widget.onTimeChange,
        // ),
      ],
    );
  }
}

==> _private_chat-0.0.12.tar.gz: lib/widgets/widget_time_picker.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:_private_core/_private_core.dart';

class WidgetTimePicker extends StatefulWidget {
  final Function(DateTime) onTimeChange;
  final DateTime? initialSelectedDate;
  const WidgetTimePicker(
      {Key? key, required this.onTimeChange, this.initialSelectedDate})
      : super(key: key);

  @override
  _WidgetTimePickerState createState() => _WidgetTimePickerState();
}

class _WidgetTimePickerState extends State<WidgetTimePicker> {
  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.center,
      children: [
        Container(
          width: Get.width,
          height: 46,
          decoration: BoxDecoration(
              color: appColors.appBGColor,
              borderRadius: BorderRadius.circular(8)),
        ),
        Text(
          ':',
          style: w700TextStyle().copyWith(
              color: appColors.text, fontWeight: FontWeight.w500, fontSize: 20),
        ),
        // TimePickerSpinner(
        //   is24HourMode: true,
        //   time: widget.initialSelectedDate,
        //   normalTextStyle:  w700TextStyle().copyWith(
        //       color: AppColors.text.withOpacity(.65),
        //       fontWeight: FontWeight.w500,
        //       fontSize: 16.5),
        //   highlightedTextStyle:  w700TextStyle().copyWith(
        //       color: AppColors.text,
        //       fontWeight: FontWeight.w500,
        //       fontSize: 20),
        //   spacing: 16,
        //   itemHeight: 55,
        //   itemWidth: 55,
        //   isForce2Digits: true,
        //   alignment: Alignment.center,
        //   onTimeChange: widget.onTimeChange,
        // ),
      ],
    );
  }
}
